@@ -358,9 +358,9 @@ class ImageHandler:
             import torch
 
             if result.ndim == 3:
-                return torch.from_numpy(result.transpose(2, 0, 1))
+                return torch.from_numpy(result.transpose(2, 0, 1).copy())
             else:
-                return torch.from_numpy(result)
+                return torch.from_numpy(result.copy())
 
         return None
 
