@@ -107,6 +107,7 @@ class WebDataset(DataPipeline, FluidInterface):
         detshuffle=False,
         nodesplitter=shardlists.single_node_only,
         select_files=None,
+        rename_files=None,
         verbose=False,
     ):
         super().__init__()
@@ -122,7 +123,7 @@ class WebDataset(DataPipeline, FluidInterface):
         elif isinstance(urls, str) and (
             urls.endswith(".yaml") or urls.endswith(".yml")
         ):
-            with (open(urls)) as stream:
+            with open(urls) as stream:
                 spec = yaml.safe_load(stream)
             assert "datasets" in spec
             self.append(shardlists.MultiShardSample(spec))
@@ -145,7 +146,9 @@ class WebDataset(DataPipeline, FluidInterface):
         if cache_dir is None or cache_size == 0:
             self.append(
                 tariterators.tarfile_to_samples(
-                    handler=handler, select_files=select_files
+                    handler=handler,
+                    select_files=select_files,
+                    rename_files=rename_files,
                 )
             )
         else:
@@ -158,9 +161,16 @@ class WebDataset(DataPipeline, FluidInterface):
                     cache_size=cache_size,
                     cache_dir=cache_dir,
                     select_files=select_files,
+                    rename_files=rename_files,
                 )
             )
 
+    def __enter__(self):
+        return self
+    
+    def __exit__(self, *args):
+        self.close()
+
 
 class FluidWrapper(DataPipeline, FluidInterface):
     """Small fluid-interface wrapper for DataPipeline."""
