@@ -1,4 +1,4 @@
-#%%
+# %%
 import copy
 import sys
 from itertools import islice
@@ -38,6 +38,13 @@ class DataPipeline(IterableDataset, PipelineStage):
             else:
                 self.pipeline.append(arg)
 
+    def close(self):
+        """Close the pipeline."""
+        for step in self.pipeline:
+            if hasattr(step, "close"):
+                step.close()
+        del self.pipeline
+
     def invoke(self, f, *args, **kwargs):
         """Apply a pipeline stage, possibly to the output of a previous stage."""
         if isinstance(f, PipelineStage):
@@ -85,6 +92,7 @@ class DataPipeline(IterableDataset, PipelineStage):
     def compose(self, *args):
         """Append a pipeline stage to a copy of the pipeline and returns the copy."""
         result = copy.copy(self)
+        result.pipeline = copy.copy(result.pipeline)
         for arg in args:
             result.append(arg)
         return result
