@@ -144,7 +144,7 @@ def tar_file_iterator(
             stream.members = []
         except Exception as exn:
             if hasattr(exn, "args") and len(exn.args) > 0:
-                exn.args = (exn.args[0] + " @ " + str(fileobj),) + exn.args[1:]
+                exn.args = (str(exn.args[0]) + " @ " + str(fileobj),) + exn.args[1:]
             if handler(exn):
                 continue
             else:
@@ -241,7 +241,7 @@ def group_by_keys(
             if suffixes is None or suffix in suffixes:
                 current_sample[suffix] = value
         except Exception as exn:
-            exn.args = exn.args + (source.get("stream"), source.get("url"))
+            exn.args = exn.args + (filesample.get("stream"), filesample.get("url"))
             if handler(exn):
                 continue
             else:
